# -*- Mode: rpm-spec -*-
#
# First: Get versions names right is complicated (tm)
# Second: kernel allways have the version & release number in the name
#         this is done to preserving a working kernel when you install 
#         a new one
# Stored in %rpmrversion & %rpmrelease
#
# We want to reflect in the kernel naming:
#   - kernel in with is based (ex. 2.6.0) 
#     this version is stored in %realversion
#   - Number of Mandrake kernel based on this vanilla kernel (ex. 1mdk).
#     stored in %mdkrelease.
#    
# That gives us a nice name: 2.6.0.1mdk
# 
# As version and release are allways fixed, name of the package is 
# going to be:
#        kernel-2.6.0.1mdk-1-1mdk
#
# Confused already?
#
# Now there arrive pre/rc kernels.  This kernels have the particularity
# that they have the name of the new kernel, but they are based in the
# tar file of the old kernel, i.e. names are basically:
#  - kernel: 2.6.0
#  - patch name: 2.6.0-pre3
#    stored in %use_patch
#  - Number of Mandrake kernel based in this pre kernel 2mdk
#
# That gives us a nice name again: 2.6.0.pre3.2mdk
# Problems now are:
#   - sublevel of kernel 0 (needed for tar file)
#   - sublevel of kernel is 1 (needed for prepatch and naming 
#     the package).
# This explains the need of %tar_version, because this will be different
# of %real_version if there is a pre/rc patch.
# 
# Still with me?
# 
# There are still a problem, when real 2.4.22 cames out, it will have
# a mane like: 
#              2.4.22.1mdk
# this name is (for rpm ordering of versions) smaller than:
#              2.4.22.pre3.2mdk
# to fix that we add a 0 to the name (and appear the need of realrelease)
# in the pre/rc
# 	       2.4.22.0.pre3.2mdk
#
# Take one aspirine.  Relax.
#
# Problem now is that names are just really ugly, and specially
# lilo/grub names are very difficult to read/type.
# Notice that the extra .0 is there only to make visual comparations 
# easy, but it is an annoyance.
#
# Lilo name for this kernel will be:
#       2422-0.pre3.2mdk
# And as everybody knows, putting dot's in lilo names is not nice.
# Then we change the kernel name (for loaders, and directory names only)
# to a more userfriendly:
# 		2.4.22pre3-2mdk
# That way, smp, enterprise versions continue to have the well known names
# in the loader of:
#		2422pre3-2smp
#
# For a non pre/rc kernel define (real examples in brakets)
#       2.6.X.Ymdk [2.6.0.2mdk]
# where
#	%sublvel = X 	[0]
#   	%mdkrelease = Y [2]
#	%use_patch 0	[0]
#
# For a pre/rc kernel do:
#	2.6.X.0.Y.Zmdk [2.6.3.0.pre3.2mdk]
# where
#	%sublvel = X 	[3]
#   	%mdkrelease = Z [2]
#	%use_patch Y	[pre3]
#
# I hope this is all clear now. If you have any doubt, please mail me at:
#
# Juan Quintela <quintela@mandrakesoft.com>

%define sublevel 3
%define mdkrelease 1
%define use_patch 0

# This is only to make life easier for people that creates derivated kernels
# a.k.a name it kernel-benh :)
%define kname  kernel-benh
%define benver 2
# Temporary rpm build fix
#%define _unpackaged_files_terminate_build 0

# You shouldn't have to change any kernel/patch/version number
# for 2.6 kernels

# When we are using a pre/rc patch, the tarball is a sublevel -1
%if %use_patch
%define tar_version 2.6.%(expr %{sublevel} - 1)-ben%{benver}
%define patchversion %{use_patch}d%{mdkrelease}.ben%{benver}
%define realrelease 0.%{use_patch}.%{benver}.ben.%{mdkrelease}mdk
%else
%define tar_version 2.6.%{sublevel}-ben%{benver}
%define patchversion d%{mdkrelease}.ben%{benver}
%define realrelease %{benver}.ben.%{mdkrelease}mdk
%endif

# never touch the folowing two fields
%define rpmversion 1
%define rpmrelease 1mdk
%define realversion 2.6.%{sublevel}
%define mdkversion %{realversion}-%{realrelease}
%define patches_ver 2.6.%{sublevel}-%{patchversion}

# having different top level names for packages means
# that you have to remove them by hand :(
%define top_dir_name %{kname}

%define build_dir ${RPM_BUILD_DIR}/%top_dir_name
%define src_dir %{build_dir}/kernel-%tar_version
%define KVERREL %{realversion}-%{realrelease}

# this is the config that contains all the drivers for the hardware/
# things that I use (Juan Quintela).
%define build_minimal 0

%define build_kheaders 1
%define build_debug 0
%define build_doc 1
%define build_source 1

%define build_100 %(if [ `awk '{print $4}' /etc/mandrake-release` = 10.0 ];then echo 1; else echo 0; fi)
%define build_92 %(if [ `awk '{print $4}' /etc/mandrake-release` = 9.2 ];then echo 1; else echo 0; fi)

%define build_up 1
%define build_smp 1
%define build_enterprise 1

%define build_BOOT 0

# End of user definitions
%{?_without_up: %global build_up 0}
%{?_without_smp: %global build_smp 0}
%{?_without_enterprise: %global build_enterprise 0}
%{?_without_BOOT: %global build_BOOT 0}
%{?_without_minimal: %global build_minimal 0}
%{?_without_debug: %global build_debug 0}
%{?_without_doc: %global build_doc 0}
%{?_without_source: %global build_source 0}

%{?_with_up: %global build_up 1}
%{?_with_smp: %global build_smp 1}
%{?_with_enterprise: %global build_enterprise 1}
%{?_with_BOOT: %global build_BOOT 1}
%{?_with_minimal: %global build_minimal 1}
%{?_with_debug: %global build_debug 1}
%{?_with_doc: %global build_doc 1}
%{?_with_source: %global build_source 1}

%{?_with_kheaders: %global build_kheaders 1}
%{?_with_92: %global build_92 1}
%{?_with_100: %global build_100 1}

%define build_nosrc 0
%{?_with_nosrc: %global build_nosrc 1}

%define kmake %make
# there are places where parallel make don't work
%define smake make

Summary: The Linux kernel (the core of the Linux operating system).
Name: %{kname}-%{mdkversion}
Version: %{rpmversion}
Release: %{rpmrelease}
License: GPL
Group: System/Kernel and hardware
ExclusiveArch: ppc ppc64
ExclusiveOS: Linux
URL: http://www.kernel.org/

####################################################################
#
# Sources
#
### This is for full SRC RPM
# rsync.theorie.physik.uni-muenchen.de::linuxppc-2.5-benh
Source0: kernel-benh-%{tar_version}.tar.bz2
### This is for stripped SRC RPM
%if %build_nosrc
NoSource: 0
%endif
#Source1: linux-%{tar_version}.tar.bz2.info

Source4: README.kernel-sources
Source5: README.Mandrake

Source15: ben-linux-mdkconfig.h
Source16: linux-merge-config.awk

Source100: linux-%{patches_ver}.tar.bz2

####################################################################
#
# Patches

#
# Patch0 to Patch100 are for core kernel upgrades.
#

# Pre linus patch: ftp://ftp.kernel.org/pub/linux/kernel/v2.6/testing

%if %use_patch
Patch1: patch-%realversion-%use_patch.bz2
%endif

#END
####################################################################

# Defines for the things that are needed for all the kernels
%define requires1 modutils >= 2.4.26-3mdk
%define requires2 mkinitrd >= 3.5.18-3mdk
%define requires3 bootloader-utils >= 1.6-4mdk
#%define requires4 udev sysfsutils module-init-tools >= 0.9.15
%define requires4 module-init-tools >= 3.0-0.pre9.2mdk
%define kprovides kernel = %{realversion}, alsa

BuildRoot: %{_tmppath}/%{name}-%{realversion}-build
Provides: module-info, %kprovides
Autoreqprov: no
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4
BuildRequires: gcc module-init-tools >= 3.0-0.pre9.2mdk

%description
The kernel package contains the Linux kernel (vmlinuz), the core of your
Mandrake Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This "benh" kernel is specially patched for PowerPC systems by Benjamin Herrenschmidt.

For instructions for update, see:
http://www.mandrakesecure.net/en/kernelupdate.php


#
# kernel-smp: Symmetric MultiProcessing kernel
#

%package -n %{kname}-smp-%{mdkversion}
Summary: The Linux Kernel compiled for SMP machines.
Group: System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-smp-%{mdkversion}
This package includes a SMP version of the Linux %{realversion} kernel. It is
required only on machines with two or more CPUs, although it should work
fine on single-CPU boxes.
This "benh" kernel is specially patched for PowerPC systems by Benjamin Herrenschmidt.

For instructions for update, see:
http://www.mandrakesecure.net/en/kernelupdate.php

#
# kernel-enterprise: Symmetric MultiProcessing kernel
#

%package -n %{kname}-enterprise-%{mdkversion}
Summary: The Linux Kernel compiled with options for Enterprise server usage.
Group: System/Kernel and hardware
Provides: %kprovides
Requires: %requires1
Requires: %requires2
Requires: %requires3
Requires: %requires4

%description -n %{kname}-enterprise-%{mdkversion}
This package includes a kernel that has appropriate configuration options
enabled for the typical large enterprise server.  This includes SMP support
for multiple processor machines, support for large memory configurations
and other appropriate items.

This "benh" kernel is specially patched for PowerPC systems by Benjamin Herrenschmidt.

#
# kernel-boot: BOOT Kernel
#

%package -n %{kname}-BOOT-%{mdkversion}
Summary: The version of the Linux kernel used on installation boot disks.
Group: System/Kernel and hardware
Url: https://kenobi.mandrakesoft.com/~chmou/kernel/BOOT/

%description -n %{kname}-BOOT-%{mdkversion}
This package includes a trimmed down version of the Linux kernel.
This kernel is used on the installation boot disks only and should not
be used for an installed system, as many features in this kernel are
turned off because of the size constraints.

This "benh" kernel is specially patched for PowerPC systems by Benjamin Herrenschmidt.

For instructions for update, see:
http://www.mandrakesecure.net/en/kernelupdate.php

%package -n %{kname}-source
Version: %{realversion}
Release: %{realrelease}
Requires: glibc-devel, ncurses-devel, make, gcc, perl
Summary: The source code for the Linux kernel.
Group: Development/Kernel
Autoreqprov: no
Provides: kernel-source

%description -n %{kname}-source
The kernel-source package contains the source code files for the Linux
kernel. These source files are needed to build most C programs, since
they depend on the constants defined in the source code. The source
files can also be used to build a custom kernel that is better tuned to
your particular hardware, if you are so inclined (and you know what you're
doing).

This "benh" kernel-source is specially patched for PowerPC systems by Benjamin Herrenschmidt.

#
# kernel-doc: documentation for the Linux kernel
#
%package -n %{kname}-doc
Version: %{version}
Release: %{release}
Summary: Various documentation bits found in the kernel source.
Group: Books/Computer books

%description -n %{kname}-doc
This package contains documentation files form the kernel source. Various
bits of information about the Linux kernel and the device drivers shipped
with it are documented in these files. You also might want install this
package if you need a reference to the options that can be passed to Linux
kernel modules at load time.



#
# End packages - here begins build stage
#
%prep
%setup -q -n %top_dir_name -c

%setup -q -n %top_dir_name -D -T -a100

%define patches_dir ../%{patches_ver}/

cd %src_dir
%if %use_patch
%patch1 -p1
%endif


%{patches_dir}/scripts/apply_patches

# PATCH END
#
# Setup Begin
#

# Prepare all the variables for calling create configs

%if %build_debug
%define debug --debug
%else
%define debug --no-debug
%endif

%if %build_minimal
%define minimal --minimal
%else
%define minimal --no-minimal
%endif

%{patches_dir}/scripts/create_configs %debug %minimal --user_cpu="%{_target_cpu}"

# make sure the kernel has the sublevel we know it has...
LC_ALL=C perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile

# get rid of unwanted files
find . -name '*~' -o -name '*.orig' -o -name '*.append' |xargs rm -f

%if %build_kheaders

kheaders_dirs=`echo $PWD/include/{asm-*,linux,sound}`

pushd %build_dir
install -d kernel-headers/
cp -a $kheaders_dirs kernel-headers/
tar cf kernel-headers-%mdkversion.tar kernel-headers/
bzip2 -9f kernel-headers-%mdkversion.tar
rm -rf kernel-headers/
# build_kheaders
%endif


%build
# Common target directories
%define _kerneldir /usr/src/linux-%{KVERREL}
%define _bootdir /boot
%define _modulesdir /lib/modules
%define _savedheaders ../../savedheaders/

# Directories definition needed for building
%define temp_root %{build_dir}/temp-root
%define temp_source %{temp_root}%{_kerneldir}
%define temp_boot %{temp_root}%{_bootdir}
%define temp_modules %{temp_root}%{_modulesdir}

PrepareKernel() {
	name=$1
	extension=$2
	echo "Make dep for kernel $extension"
	%smake -s mrproper

	# We can't use only defconfig anyore because we have the autoconf patch,

	if [ -z "$name" ]; then
		config_name="defconfig"
	else
		config_name="defconfig-$name"
	fi

	# make sure EXTRAVERSION says what we want it to say
	LC_ALL=C perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -$extension/" Makefile
	cp arch/%{_arch}/$config_name .config
	%smake oldconfig
}

BuildKernel() {
	KernelVer=$1
	echo "Building kernel $KernelVer"

	%kmake all

	## Start installing stuff
	install -d %{temp_boot}
	install -m 644 System.map %{temp_boot}/System.map-$KernelVer
	install -m 644 .config %{temp_boot}/config-$KernelVer

	#ifarch ppc
	cp -f vmlinux %{temp_boot}/vmlinuz-$KernelVer
	cp -f arch/ppc/boot/images/zImage.chrp-rs6k %{temp_boot}/vmlinuz-rs6k-$KernelVer
	#endif

	# modules
	install -d %{temp_modules}/$KernelVer
	%smake INSTALL_MOD_PATH=%{temp_root} KERNELRELEASE=$KernelVer modules_install 
}

SaveHeaders() {
	flavour=$1
	flavour_name="`echo $flavour | sed 's/-/_/g'`"
%if %build_source
	HeadersRoot=%{temp_source}/savedheaders
	HeadersArch=$HeadersRoot/%{_target_cpu}/$flavour
	echo "Saving hearders for $flavour %{_target_cpu}"

	# deal with the kernel headers that are version specific
	install -d $HeadersArch
	install -m 644 include/linux/autoconf.h $HeadersArch/autoconf.h
	install -m 644 include/linux/version.h $HeadersArch/version.h
	if [ "$flavour" != "BOOT" ]; then
		grep -e " __crc_" -e " __ksymtab_" System.map > include/linux/symtab-$flavour
	fi
    	echo "%{_target_cpu} $flavour_name %{_savedheaders}%{_target_cpu}/$flavour/" >> $HeadersRoot/list
%endif
}

CreateFiles() {
	kversion=$1
	output=../kernel_files.$kversion

	echo "%defattr(-,root,root)" > $output
	echo "%{_bootdir}/config-${kversion}" >> $output
%ifarch sparc sparc64
	echo "%{_bootdir}/vmlinux-${kversion}" >> $output
%else
	echo "%{_bootdir}/vmlinuz-${kversion}" >> $output
%endif
%ifarch ppc
	echo "%{_bootdir}/vmlinuz-rs6k-${kversion}" >> $output
%endif
	echo "%{_bootdir}/System.map-${kversion}" >> $output
	echo "%dir %{_modulesdir}/${kversion}/" >> $output
	echo "%{_modulesdir}/${kversion}/kernel" >> $output
	echo "%{_modulesdir}/${kversion}/modules.*" >> $output
	echo "%doc README.kernel-sources" >> $output
	echo "%doc README.Mandrake" >> $output
}

CreateKernel() {
	flavour=$1

	if [ "$flavour" = "up" ]; then
		KernelVer=%{KVERREL}
		PrepareKernel "" %realrelease
	else
		KernelVer=%{KVERREL}$flavour
		PrepareKernel $flavour %{realrelease}$flavour
	fi

	BuildKernel $KernelVer
	SaveHeaders $flavour
        CreateFiles $KernelVer
}


CreateKernelNoName() {
	arch=$1
	nprocs=$2
	memory=$3

        name=$arch-$nprocs-$memory
	extension="%realrelease-$name"

	KernelVer="%{KVERREL}-$arch-$nprocs-$memory"
	PrepareKernel $name $extension
	BuildKernel $KernelVer
	SaveHeaders $name
        CreateFiles $KernelVer
}

###
# DO it...
###

# Create a simulacro of %buildroot
rm -rf %{temp_root}
install -d %{temp_root}

#make sure we are in the directory
cd %src_dir

%if %build_BOOT
CreateKernel BOOT
%endif

%if %build_smp
CreateKernel smp
%endif

%if %build_enterprise
CreateKernel enterprise
%endif

%if %build_up
CreateKernel up
%endif

# We don't make to repeat the depend code at the install phase
%if %build_source
PrepareKernel "" %{realrelease}custom
%smake -s prepare-all
%endif

###
### install
###
%install
install -m 644 %{SOURCE4}  .
install -m 644 %{SOURCE5}  .

cd %src_dir
# Directories definition needed for installing
%define target_source %{buildroot}/%{_kerneldir}
%define target_boot %{buildroot}%{_bootdir}
%define target_modules %{buildroot}%{_modulesdir}

# We want to be able to test several times the install part
rm -rf %{buildroot}
cp -a %{temp_root} %{buildroot}

# Create directories infastructure
%if %build_source
install -d %{target_source} 

tar cf - . | tar xf - -C %{target_source}
# ln -sf linux-%{KVERREL} %{buildroot}/usr/src/linux
chmod -R a+rX %{target_source}

# we remove all the source files that we don't ship

# first architecture files
for i in arm cris ia64 mips mips64 parisc ppc64 s390 s390x sh sh64 arm26 h8300 m68knommu v850; do
	rm -rf %{target_source}/arch/$i
	rm -rf %{target_source}/include/asm-$i
done
# ppc needs m68k headers
rm -rf %{target_source}/arch/m68k

# remove config split dir
rm -rf %{target_source}/include/config

# other misc files
rm -f %{target_source}/{.config.old,.config.cmd}

pushd %{target_source}/include/linux ; {
install -m 644 %{SOURCE15} rhconfig.h
rm -rf autoconf.h version.h
# Create autoconf.h file
echo '#include <linux/rhconfig.h>' > autoconf.h
sed 's,$,autoconf.h,' %{_savedheaders}list | awk -f %{SOURCE16} >> autoconf.h
# Create version.h
echo "#include <linux/rhconfig.h>" > version.h
loop_cnt=0
for i in BOOT up smp enterprise; do
	if [ -d %{_savedheaders}%{_target_cpu}/$i -a \
	     -f %{_savedheaders}%{_target_cpu}/$i/version.h ]; then
		name=`echo $i | sed 's/-/_/g'`
		if [ $loop_cnt = 0 ]; then
      			buf="#if defined(__module__$name)"
    		else
 	     		buf="#elif defined(__module__$name)"
    		fi
		echo "$buf" >> version.h
		grep UTS_RELEASE %{_savedheaders}%{_target_cpu}/$i/version.h >> version.h
		loop_cnt=$[loop_cnt + 1]
	fi
done
#write last lines
if [ $loop_cnt -eq 0 ]; then
	echo "You need to build at least one kernel"
	exit 1;
fi
echo "#else" >> version.h
echo '#define UTS_RELEASE "'%{KVERREL}custom'"' >> version.h
echo "#endif" >> version.h

# Any of the version.h are ok, as they only differ in the first line
ls %{_savedheaders}%{_target_cpu}/*/version.h | head -n 1 | xargs grep -v UTS_RELEASE >> version.h
rm -rf %{_savedheaders}
} ; popd
#endif %build_source
%endif

# We used to have a copy of PrepareKernel here
# Now, we make sure that the thing in the linux dir is what we want it to be
# Gzip module and relink the link to a .gz module

find %{target_modules} -type f -name '*.ko'|xargs gzip -9f
for i in $(find %{target_modules} -type l -name '*.ko');do
    link=$(LC_ALL=C perl -e 'print readlink shift, "\n"' $i)
    ln -s $link.gz $i.gz
    rm -f $i
done

for i in %{target_modules}/*; do
  rm -f $i/build $i/modules.*
  rm -rf  $i/pcmcia/
done

# sniff, if we gzipped all the modules, we change the stamp :(
# we really need the depmod -ae here

pushd %{target_modules}
for i in *; do
	/sbin/depmod-25 -u -ae -b %{buildroot} -r -F %{target_boot}/System.map-$i $i
	echo $?
done

for i in *; do
	pushd $i
	echo "Creating module.description for $i"
	find . -name "*.ko" -o -name "*.ko.gz" \
	|xargs -i echo 'echo -ne `basename {}`"\t\t"; echo `/sbin/modinfo-25 -d {}`' \
	> get-desc.sh
	sh get-desc.sh > modules.desc
	rm get-desc.sh
        #modules=`find . -name "*.ko" -o -name "*.ko.gz"`
        #/sbin/modinfo-25 -F 'description' $modules \
        #| perl -lne 'print "$1\t$3" if m|([^/]*)\.ko(\.gz)? "(.*)"|'  > modules.description
	popd
     done
popd


###
### clean
###

%clean
rm -rf %{buildroot}
# We don't want to remove this, the whole reason of its existence is to be 
# able to do several rpm --short-circuit -bi for testing install 
# phase without repeating compilation phase
#rm -rf %{temp_root} 

###
### scripts
###

%define options_preun -a -R -S -c
%define options_post -a -s -c -L

%preun
/sbin/installkernel %options_preun %{KVERREL}
exit 0

%post
/sbin/installkernel %options_post %{KVERREL}

%postun
/sbin/kernel_remove_initrd %{KVERREL}


%preun -n %{kname}-smp-%{mdkversion}
/sbin/installkernel %options_preun %{KVERREL}smp
exit 0

%post -n %{kname}-smp-%{mdkversion}
/sbin/installkernel %options_post %{KVERREL}smp

%postun -n %{kname}-smp-%{mdkversion}
/sbin/kernel_remove_initrd %{KVERREL}smp


%preun -n %{kname}-enterprise-%{mdkversion}
/sbin/installkernel %options_preun %{KVERREL}enterprise
exit 0

%post -n %{kname}-enterprise-%{mdkversion}
/sbin/installkernel %options_post %{KVERREL}enterprise

%postun -n %{kname}-enterprise-%{mdkversion}
/sbin/kernel_remove_initrd %{KVERREL}enterprise


%preun -n %{kname}-BOOT-%{mdkversion}
/sbin/installkernel %options_preun %{KVERREL}BOOT
exit 0

%post -n %{kname}-BOOT-%{mdkversion}
/sbin/installkernel %options_post %{KVERREL}BOOT

%postun -n %{kname}-BOOT-%{mdkversion}
/sbin/kernel_remove_initrd %{KVERREL}BOOT


%post -n %{kname}-source
cd /usr/src
rm -f linux
ln -snf linux-%{KVERREL} linux
/sbin/service kheader start 2>/dev/null >/dev/null || :
# we need to create /build only when there is a source tree.

for i in /lib/modules/%{KVERREL}*; do
	if [ -d $i ]; then
		ln -sf /usr/src/linux-%{KVERREL} $i/build
	fi
done

%postun -n %{kname}-source
if [ -L /usr/src/linux ]; then 
    if [ -L /usr/src/linux -a `ls -l /usr/src/linux 2>/dev/null| awk '{ print $11 }'` = "linux-%{KVERREL}" ]; then
	[ $1 = 0 ] && rm -f /usr/src/linux
    fi
fi
# we need to delete <modules>/build at unsinstall
for i in /lib/modules/%{KVERREL}*/build; do
	if [ -L $i ]; then
		rm -f $i
	fi
done
exit 0

###
### file lists
###

%if %build_up
%files -f kernel_files.%{KVERREL}
%endif

%if %build_smp
%files -n %{kname}-smp-%{mdkversion} -f kernel_files.%{KVERREL}smp
%endif

%if %build_enterprise
%files -n %{kname}-enterprise-%{mdkversion} -f kernel_files.%{KVERREL}enterprise
%endif

%if %build_BOOT
%files -n %{kname}-BOOT-%{mdkversion} -f kernel_files.%{KVERREL}BOOT
%endif

%if %build_source
%files -n %{kname}-source
%defattr(-,root,root)
%dir %{_kerneldir}
%dir %{_kerneldir}/arch
%dir %{_kerneldir}/include
%{_kerneldir}/.config
%{_kerneldir}/COPYING
%{_kerneldir}/CREDITS
%{_kerneldir}/Documentation
%{_kerneldir}/MAINTAINERS
%{_kerneldir}/Makefile
%{_kerneldir}/README
#for benh:
%{_kerneldir}/TODO
%{_kerneldir}/REPORTING-BUGS
%{_kerneldir}/arch/alpha
%{_kerneldir}/arch/i386
#%{_kerneldir}/arch/ia64
%{_kerneldir}/arch/ppc
%{_kerneldir}/arch/sparc
%{_kerneldir}/arch/sparc64
%{_kerneldir}/arch/x86_64
%{_kerneldir}/arch/um
%{_kerneldir}/crypto
%{_kerneldir}/drivers
%{_kerneldir}/fs
%{_kerneldir}/init
%{_kerneldir}/ipc
%{_kerneldir}/kdb
%{_kerneldir}/kernel
%{_kerneldir}/lib
%{_kerneldir}/mm
%{_kerneldir}/net
%{_kerneldir}/security
%{_kerneldir}/scripts
%{_kerneldir}/sound
%{_kerneldir}/usr
%{_kerneldir}/3rdparty
%{_kerneldir}/include/acpi
%{_kerneldir}/include/asm-alpha
%{_kerneldir}/include/asm-generic
%{_kerneldir}/include/asm-i386
#%{_kerneldir}/include/asm-ia64
# This is needed by ppc
%{_kerneldir}/include/asm-m68k
%{_kerneldir}/include/asm-ppc
%{_kerneldir}/include/asm-sparc
%{_kerneldir}/include/asm-sparc64
%{_kerneldir}/include/asm-x86_64
%{_kerneldir}/include/asm-um
%{_kerneldir}/include/asm
%{_kerneldir}/include/linux
%{_kerneldir}/include/math-emu
%{_kerneldir}/include/net
%{_kerneldir}/include/pcmcia
%{_kerneldir}/include/scsi
%{_kerneldir}/include/sound
%{_kerneldir}/include/video
%{_kerneldir}/include/media
%{_kerneldir}/include/rxrpc
%doc README.kernel-sources
%doc README.Mandrake
#endif %build_source
%endif

%if %build_doc
%files -n %{kname}-doc
%defattr(-,root,root)
%doc kernel-%{tar_version}/Documentation/*
%endif

%changelog
* Sun Feb 22 2004 Danny Tholen <obiwan@mailmij.org> 2.6.3-2.ben.1mdk
- benh-2.6 spec file based on Thomas' and Stews kernels
- 2.6.3ben2 source
- additional patches:
  * fixes from mdk kernel
  * supermount
  * lufs
  * cifs
  * laptop mode
  * some extra drivers 
